Learn R Programming

onlineBcp (version 0.1.8)

online_cp: Online change point detection algorithm for normally distributed data.

Description

Online change point detection algorithm for normally distributed data.

Usage

online_cp(x, theta = 0.9, alpha = 1, beta = 1, th_cp = 0.5, debug = FALSE)

Arguments

x

the normalized data

theta

the probability of occurrence of a change point, default 0.9

alpha

the hyperparameter of posterior distribution, default 1.0

beta

the hyperparameter of posterior distribution, default 1.0

th_cp

threshold level for the posterior distribution of change point, default 0.5

debug

a logical value, when TRUE, will print more information

Value

An object of the BayesCP class