Online change point detection algorithm for normally distributed data.
online_cp(x, theta = 0.9, alpha = 1, beta = 1, th_cp = 0.5, debug = FALSE)the normalized data
the probability of occurrence of a change point, default 0.9
the hyperparameter of posterior distribution, default 1.0
the hyperparameter of posterior distribution, default 1.0
threshold level for the posterior distribution of change point, default 0.5
a logical value, when TRUE, will print more information
An object of the BayesCP class